# frozen_string_literal: true

%w[
  bundler
].each(&method(:require))

%w[
  config/fetcher
  config/file_finder
  commands
  version
  errors
  voting
].each { |file| require "bundler/security/#{file}" }

%w[
  build_unsafe_gem
  build_success
  build_failure
  gem_policy
  remote_policy
  request
  versions/local
  versions/remote
].each { |file| require "bundler/security/voting/#{file}" }

# Bundler main namespace
module Bundler
  # Plugin responsible for safe gem installation
  module Security
    class << self
      # Registers the plugin and add before install all hook
      def register
        return if defined?(@registered) && @registered

        @registered = true

        Bundler::Plugin.add_hook('before-install-all') do |_|
          Bundler::Security::Voting.call(
            command,
            build_definition
          )
        end
      end

      # Build clean instance of bundler definition, as we don't want to pollute the main one
      #
      # @return [Bundler::Definition]
      def build_definition
        Bundler.configure

        Bundler::Definition.build(
          Bundler.default_gemfile,
          Bundler.default_lockfile,
          true
        )
      end

      # Command that was run with bundle
      #
      # @return [String]
      def command
        ARGV
          .first
          .then { |value| value || Bundler::Security::Commands::INSTALL }
      end
    end
  end
end
