# frozen_string_literal: true

module Bundler
  module Security
    # Module for all the components related to setting up the config
    module Config
      # Class responsible for fetching the config from .coditsu.yml
      module Fetcher
        class << self
          # @param build_path [String] path of the current build
          # @return [OpenStruct] open struct with config details
          # @example
          #   details = Fetcher.new.call('./')
          #   details.build_path #=> './'
          def call(build_path)
            FileFinder
              .call(build_path)
              .then(&File.method(:read))
              .then(&ERB.method(:new))
              .then(&:result)
              .then(&YAML.method(:load))
              .then { |data| data.merge(build_path: build_path) }
              .then(&OpenStruct.method(:new))
          end
        end
      end
    end
  end
end
