# frozen_string_literal: true

module Bundler
  module Security
    module Voting
      # Build failure security verdict
      module BuildFailure
        class << self
          # Prints failure security verdict
          #
          # @param policy_type [String]
          # @param command [String] either install or update
          # @param errors [Array] detected security errors
          def call(policy_type, command, errors)
            Bundler.ui.error(
              build(policy_type, command, errors)
            )
          end

          # Builds failure security verdict message
          #
          # @param policy_type [String]
          # @param command [String] either install or update
          # @param errors [Array] detected security errors
          #
          # @return [String]
          def build(policy_type, command, errors)
            [
              "\n",
              message_type(policy_type),
              ", blocking #{command}",
              "\n\n",
              errors.join("\n"),
              "\n\n"
            ].join
          end

          # Builds a message based on policy type
          #
          # @param policy_type [String]
          #
          # @return [String]
          #
          # @raise InvalidPolicyType if policy type was not recognized
          def message_type(policy_type)
            case policy_type
            when 'organization'
              'Not enough reviews on your organization'
            when 'community'
              'Not enough reviews in the community'
            else
              raise InvalidPolicyType, policy_type
            end
          end
        end
      end
    end
  end
end
