# frozen_string_literal: true

module Bundler
  module Security
    module Voting
      # Build successful security verdict
      module BuildSuccess
        class << self
          # Prints successful security verdict
          #
          # @param policy_type [String]
          # @param command [String] either install or update
          def call(policy_type, command)
            Bundler.ui.confirm(
              build(policy_type, command)
            )
          end

          # Builds successful security verdict message
          #
          # @param policy_type [String]
          # @param command [String] either install or update
          #
          # @return [String]
          def build(policy_type, command)
            [
              "\n",
              message_type(policy_type),
              ", commencing #{command}",
              "\n\n"
            ].join
          end

          # Builds a message based on policy type
          #
          # @param policy_type [String]
          #
          # @return [String]
          #
          # @raise InvalidPolicyType if policy type was not recognized
          def message_type(policy_type)
            case policy_type
            when 'organization'
              'All gems approved by your organization'
            when 'community'
              'All gems approved by community'
            else
              raise InvalidPolicyType, policy_type
            end
          end
        end
      end
    end
  end
end
